@@ -3,7 +3,8 @@ from .utils import logger
 from .models import (
     PrescriptionItem, MagasinService, LogAstus, TopFive,
     HistoriqueMultidoses, MessageAstus, FListeError,
-    Service
+    Service, WebviewTaquin, WebviewDemiTaquin,
+    WebviewEmplacement, WebviewPatientHisto
 )
 
 
@@ -23,7 +24,10 @@ class DbMigrator:
         self.check_model('f_histo_multidoses', HistoriqueMultidoses)
         self.check_model('f_message_astus', MessageAstus)
         self.check_model('f_liste_error', FListeError)
+        self.check_field('f_user', 'x_astup', "ALTER TABLE f_user ADD COLUMN x_astup tinyint(1) DEFAULT '0';")
+        self.check_field('f_user', 'x_inventaire', "ALTER TABLE f_user ADD COLUMN x_inventaire tinyint(1) DEFAULT '0';")
         self.check_field('f_user', 'x_login', "ALTER TABLE f_user ADD COLUMN x_login VARCHAR(30) DEFAULT '';")
+        self.check_field('f_user', 'x_badge', "ALTER TABLE f_user ADD COLUMN x_badge varchar(16) DEFAULT '';")
         self.check_field('f_user', 'x_email', "ALTER TABLE f_user ADD COLUMN x_email VARCHAR(320) DEFAULT '';")
         self.check_field('f_user', 'x_import_flag',
                          "ALTER TABLE f_user ADD COLUMN x_import_flag TINYINT(1) NULL DEFAULT 0;")
@@ -33,7 +37,28 @@ class DbMigrator:
         self.check_field('f_profil', 'x_edit', "ALTER TABLE f_profil ADD COLUMN x_edit TINYINT(1) NULL DEFAULT 0;")
         self.check_field('f_ref', 'x_com_med', "ALTER TABLE f_ref ADD COLUMN x_com_med TEXT DEFAULT '';")
         self.check_field('f_ref', 'x_bac', "ALTER TABLE f_ref ADD COLUMN x_bac INT(11) NULL DEFAULT 0;")
+        # Table f_dest for Carnet and Riedl Exit
+        self.check_field('f_dest', 'x_type_carnet',
+                         "ALTER TABLE f_dest ADD COLUMN x_type_carnet INT(11) NULL DEFAULT '1'")
+        self.check_field('f_dest', 'x_secteur', "ALTER TABLE f_dest ADD COLUMN x_secteur VARCHAR(40) NULL DEFAULT ''")
+        self.check_field('f_dest', 'x_adr1', "ALTER TABLE f_dest ADD COLUMN x_adr1 VARCHAR(40) NULL DEFAULT ''")
+        self.check_field('f_dest', 'x_adr2', "ALTER TABLE f_dest ADD COLUMN x_adr2 VARCHAR(40) NULL DEFAULT ''")
+        self.check_field('f_dest', 'x_adr3', "ALTER TABLE f_dest ADD COLUMN x_adr3 VARCHAR(40) NULL DEFAULT ''")
+        self.check_field('f_dest', 'x_adr4', "ALTER TABLE f_dest ADD COLUMN x_adr4 VARCHAR(40) NULL DEFAULT ''")
+        self.check_field('f_mag', 'x_split_liste',
+                         "ALTER TABLE f_mag ADD COLUMN x_split_liste TINYINT(1) NULL DEFAULT 0;")
+        self.check_field('f_mag', 'x_libelle',
+                         "ALTER TABLE f_mag ADD COLUMN x_libelle varchar(35) NOT NULL DEFAULT '';")
+        self.check_field('f_poste', 'x_proc_pid', "ALTER TABLE f_poste ADD COLUMN x_proc_pid INT(11) NULL DEFAULT 0;")
+
         self.add_service('DEENOVA', 'Service de test')
+        # TODO: Drop all view before restore (force mode ?)
+        logger.info('Check views')
+        self.check_sql_view('webview_taquin', WebviewTaquin)
+        self.check_sql_view('webview_demi_taquin', WebviewDemiTaquin)
+        self.check_sql_view('webview_emplacement', WebviewEmplacement)
+        self.check_sql_view('webview_patient_histo', WebviewPatientHisto)
+        logger.info('End check views')
 
     def check_model(self, table_name, model_class):
         """Check if table exists, and create it if missing"""
@@ -45,6 +70,14 @@ class DbMigrator:
 
         return True
 
+    def check_sql_view(self, view_name, model_class):
+        """Check if view exists, if not create it"""
+        vws = [v.name for v in self.db.get_views()]
+        if view_name not in vws:
+            logger.info(' -> View %s is missing, we create it' % view_name)
+            kls = model_class()
+            kls.create_view()
+
     def check_field(self, table_name, field_name, ddl_str=None):
         """check if the field exists"""
         field_found = False
